# Standard Evaluator

This project expands the capabilities of the OpenMDAO components. It was developed under NASA Contract 80GRC023CA045.

Note that this is a very early prototype. We are actively working on improving the documentation and descriptions.

## Installation

`pip install standard-evaluator`

Optionally clone the repo and install locally.

- The docs folder contains the source code of the documentation, which includes the demos. Note that this has not been moved here yet.
- Experimenting is a folder we use to experiment with code. 
- The src folder contains the actual source code of the standard evaluator.
- Finally the tests folder contains our unit tests.
